==> libdap_3.6.2.orig.tar.gz: libdap-3.6.2.orig/PassiveInt32.h <==

// -*- mode: c++; c-basic-offset:4 -*-

// This file is part of libdap, A C++ implementation of the OPeNDAP Data
// Access Protocol.

// Copyright (c) 2002,2003 OPeNDAP, Inc.
// Author: James Gallagher <jgallagher@opendap.org>
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
// 
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
// (c) COPYRIGHT URI/MIT 1994-1999
// Please read the full copyright statement in the file COPYRIGHT_URI.
//
// Authors:
//      pwest       Patrick West <pwest@ucar.edu>

// Interface for PassiveInt32 type. 
//
// pwest 11/04/03

#ifndef _passiveint32_h
#define _passiveint32_h 1


#include "Int32.h"
#include "dods-datatypes.h"

/** @brief Holds a 32-bit signed integer. 

    @see BaseType
    */

class PassiveInt32: public Int32 {
public:
    PassiveInt32(const string &n = "");

    PassiveInt32(const PassiveInt32 &copy_from);

    PassiveInt32 &operator=(const PassiveInt32 &rhs);

    virtual ~PassiveInt32();

    virtual BaseType *ptr_duplicate();

    virtual bool read( const string &dataset ) ;

    virtual bool set_value( dods_int32 val ) ;
};

#endif // _passiveint32_h

==> libdap-3.7.8.tar.gz: libdap-3.7.8/PassiveInt32.h <==

// -*- mode: c++; c-basic-offset:4 -*-

// This file is part of libdap, A C++ implementation of the OPeNDAP Data
// Access Protocol.

// Copyright (c) 2002,2003 OPeNDAP, Inc.
// Author: James Gallagher <jgallagher@opendap.org>
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.

// (c) COPYRIGHT URI/MIT 1994-1999
// Please read the full copyright statement in the file COPYRIGHT_URI.
//
// Authors:
//      pwest       Patrick West <pwest@ucar.edu>

// Interface for PassiveInt32 type.
//
// pwest 11/04/03

#ifndef _passiveint32_h
#define _passiveint32_h 1


#include "Int32.h"
#include "dods-datatypes.h"

/** @brief Holds a 32-bit signed integer.

    @see BaseType
    */

class PassiveInt32: public Int32
{
public:
    PassiveInt32(const string &n = "");

    PassiveInt32(const PassiveInt32 &copy_from);

    PassiveInt32 &operator=(const PassiveInt32 &rhs);

    virtual ~PassiveInt32();

    virtual BaseType *ptr_duplicate();

    virtual bool read(const string &dataset) ;

    virtual bool set_value(dods_int32 val) ;
};

#endif // _passiveint32_h
